<?php
/*
** ZABBIX
** Copyright (C) 2000-2008 SIA Zabbix
**
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
**/
?>
<?php
	global $TRANSLATION;

	$TRANSLATION=array(

	'S_DATE_FORMAT_YMDHMS'=>			'd M H:i:s',
	'S_DATE_FORMAT_YMD'=>			'd M Y',
	'S_HTML_CHARSET'=>			'UTF-8',
	'S_ACTIVATE_SELECTED'=>			'Activar',
	'S_DISABLE_SELECTED'=>			'Desactivar',
	'S_DELETE_SELECTED'=>			'Eliminar',
	'S_COPY_SELECTED_TO'=>			'Copiar a ...',
	'S_HOST_IP'=>			'IP del equipo',
	'S_SERVICE_TYPE'=>			'Tipo de servicio',
	'S_SERVICE_PORT'=>			'Puerto del servicio',
	'S_DISCOVERY_STATUS'=>			'Estado del descubrimiento',
	'S_RECEIVED_VALUE'=>			'Valor recibido',
	'S_UPTIME_DOWNTIME'=>			'Tiempo operativo/Tiempo inoperativo',
	'S_DISCOVERY_RULE'=>			'Regla de descubrimiento',
	'S_DISCOVERY'=>			'Descubrimiento',
	'S_DISCOVERY_BIG'=>			'REGLAS DE DESCUBRIMIENTO',
	'S_CONFIGURATION_OF_DISCOVERY'=>			'Configuración de descubrimiento',
	'S_CONFIGURATION_OF_DISCOVERY_BIG'=>			'CONFIGURACIÓN DE DESCUBRIMIENTO',
	'S_NO_DISCOVERY_RULES_DEFINED'=>			'No se han definido reglas de descubrimiento',
	'S_IP_RANGE'=>			'Rango de IP\'s',
	'S_CHECKS'=>			'Comprobaciones',
	'S_CREATE_RULE'=>			'Crear Regla',
	'S_DELETE_RULE_Q'=>			'¿Eliminar la regla?',
	'S_EVENT_SOURCE'=>			'Origen del evento',
	'S_NEW_CHECK'=>			'Nueva comprobación',
	'S_SSH'=>			'SSH',
	'S_LDAP'=>			'LDAP',
	'S_SMTP'=>			'SMTP',
	'S_FTP'=>			'FTP',
	'S_HTTP'=>			'HTTP',
	'S_POP'=>			'POP',
	'S_NNTP'=>			'NNTP',
	'S_IMAP'=>			'IMAP',
	'S_TCP'=>			'TCP',
	'S_PORTS_SMALL'=>			'puertos',
	'S_DISCOVERY_RULES_DELETED'=>			'Reglas de descubrimiento eliminadas',
	'S_DISCOVERY_RULE_DELETED'=>			'Regla de descubrimiento eliminada',
	'S_CANNOT_DELETE_DISCOVERY_RULE'=>			'No es posible eliminar la regla',
	'S_DISCOVERY_RULES_UPDATED'=>			'Reglas de descubrimiento actualizadas',
	'S_DISCOVERY_RULE_UPDATED'=>			'Regla de descubrimiento actualizada',
	'S_CANNOT_UPDATE_DISCOVERY_RULE'=>			'No es posible actualizar la regla',
	'S_DISCOVERY_RULE_ADDED'=>			'Regla de descubrimiento añadida',
	'S_CANNOT_ADD_DISCOVERY_RULE'=>			'No es posible añadir la regla',
	'S_STATUS_OF_DISCOVERY_BIG'=>			'ESTADO DEL DESCUBRIMIENTO',
	'S_STATUS_OF_DISCOVERY'=>			'Estado del descubrimiento',
	'S_DETAILS_OF_SCENARIO'=>			'Detalles del escenario',
	'S_DETAILS_OF_SCENARIO_BIG'=>			'DETALLES DEL ESCENARIO',
	'S_SPEED'=>			'Velocidad',
	'S_RESPONSE_CODE'=>			'Código de respuesta',
	'S_TOTAL_BIG'=>			'TOTAL',
	'S_RESPONSE_TIME'=>			'Tiempo de respuesta',
	'S_IN_PROGRESS'=>			'En progreso',
	'S_OF_SMALL'=>			'En',
	'S_IN_CHECK'=>			'En la comprobación',
	'S_IDLE_TILL'=>			'Inactivo hasta',
	'S_FAILED_ON'=>			'Ha fallado en',
	'S_STATUS_OF_WEB_MONITORING'=>			'Estado de la monitorización Web',
	'S_STATUS_OF_WEB_MONITORING_BIG'=>			'ESTADO DE LA MONITORIZACIÓN WEB',
	'S_STATE'=>			'Estado',
	'S_STATUS_CODES'=>			'Códigos de estado',
	'S_WEB'=>			'Web',
	'S_CONFIGURATION_OF_WEB_MONITORING'=>			'Configuración de la monitorización Web',
	'S_CONFIGURATION_OF_WEB_MONITORING_BIG'=>			'CONFIGURACIÓN DE LA MONITORIZACIÓN WEB',
	'S_SCENARIO'=>			'Escenario',
	'S_SCENARIOS'=>			'Escenarios',
	'S_SCENARIOS_BIG'=>			'ESCENARIOS',
	'S_CREATE_SCENARIO'=>			'Crear escenario',
	'S_HIDE_DISABLED_SCENARIOS'=>			'Ocultar escenarios desactivados',
	'S_SHOW_DISABLED_SCENARIOS'=>			'Mostrar escenarios desactivados',
	'S_NUMBER_OF_STEPS'=>			'Número de pasos',
	'S_SCENARIO_DELETED'=>			'Escenario eliminado',
	'S_SCENARIO_ACTIVATED'=>			'Escenario activado',
	'S_SCENARIO_DISABLED'=>			'Escenario deshabilitado',
	'S_DELETE_SCENARIO_Q'=>			'¿Eliminar escenario?',
	'S_SCENARIO_UPDATED'=>			'Escenario actualizado',
	'S_CANNOT_UPDATE_SCENARIO'=>			'No es posible actualizar el escenario',
	'S_SCENARIO_ADDED'=>			'Escenario añadido',
	'S_CANNOT_ADD_SCENARIO'=>			'No es posible añadir el escenario',
	'S_CANNOT_DELETE_SCENARIO'=>			'No es posible eliminar el escenario',
	'S_AGENT'=>			'Agente',
	'S_VARIABLES'=>			'Variables',
	'S_STEP'=>			'Paso',
	'S_STEPS'=>			'Pasos',
	'S_TIMEOUT'=>			'Timeout',
	'S_POST'=>			'Post',
	'S_REQUIRED'=>			'Requerido',
	'S_STEP_OF_SCENARIO'=>			'Paso del escenario',
	'S_ELEMENT'=>			'Grupo',
	'S_ELEMENTS'=>			'Elementos',
	'S_ONLY_HOST_INFO'=>			'Sólo información del equipo',
	'S_EXPORT_IMPORT'=>			'Exportar/Importar',
	'S_IMPORT_FILE'=>			'Fichero para importar',
	'S_IMPORT'=>			'Importar',
	'S_IMPORT_BIG'=>			'IMPORTAR',
	'S_EXPORT'=>			'Exportar',
	'S_EXPORT_BIG'=>			'EXPORTAR',
	'S_PREVIEW'=>			'Previsualizar',
	'S_BACK'=>			'Retroceder',
	'S_NO_DATA_FOR_EXPORT'=>			'No existen datos para exportar',
	'S_RULES'=>			'Reglas aplicables a cada grupo',
	'S_EXISTING'=>			'Si existe',
	'S_MISSING'=>			'Si no existe',
	'S_REFRESH'=>			'Refrescar',
	'S_PREVIOUS'=>			'Anterior',
	'S_NEXT'=>			'Siguiente',
	'S_RETRY'=>			'Reintentar',
	'S_FINISH'=>			'Finalizar',
	'S_FAIL'=>			'Ha fallado',
	'S_UPDATE_BIG'=>			'ACTUALIZACIÓN',
	'S_INSTALLATION'=>			'Instalación',
	'S_NEW_INSTALLATION'=>			'Nueva instalación',
	'S_NEW_INSTALLATION_BIG'=>			'NUEVA INSTALACIÓN',
	'S_INSTALLATION_UPDATE'=>			'Instalación/Actualización',
	'S_TIME_ZONE'=>			'Zona horaria',
	'S_DO_NOT_KEEP_HISTORY_OLDER_THAN'=>			'No mantener el histórico más de (en días)',
	'S_DO_NOT_KEEP_TRENDS_OLDER_THAN'=>			'No mantener las tendencias más de (en días)',
	'S_MASTER_NODE'=>			'Nodo maestro',
	'S_CHILD'=>			'Remoto',
	'S_MASTER'=>			'Maestro',
	'S_NODE_UPDATED'=>			'Nodo actualizado',
	'S_CANNOT_UPDATE_NODE'=>			'No es posible actualizar el nodo',
	'S_NODE_ADDED'=>			'Nodo añadido',
	'S_CANNOT_ADD_NODE'=>			'No es posible añadir el nodo',
	'S_NODE_DELETED'=>			'Nodo eliminado',
	'S_CANNOT_DELETE_NODE'=>			'No es posible eliminar el nodo',
	'S_CURRENT_NODE'=>			'Nodo actual',
	'S_ACKNOWLEDGES'=>			'Aceptadas',
	'S_ACKNOWLEDGE'=>			'Aceptada',
	'S_ACKNOWLEDGE_ALARM_BY'=>			'Alarma aceptada por',
	'S_ADD_COMMENT_BY'=>			'Comentario añadido por',
	'S_ALARM_ACKNOWLEDGES_BIG'=>			'ALARMAS ACEPTADAS',
	'S_ACKNOWLEDGE_ADDED'=>			'Aceptación añadida',
	'S_CONFIGURATION_OF_ACTIONS'=>			'Configuración de acciones',
	'S_CONFIGURATION_OF_ACTIONS_BIG'=>			'CONFIGURACIÓN DE ACCIONES',
	'S_OPERATION_TYPE'=>			'Operación a realizar',
	'S_SEND_MESSAGE'=>			'Enviar mensaje',
	'S_REMOTE_COMMAND'=>			'Comando remoto',
	'S_REMOTE_COMMANDS'=>			'Comandos remotos',
	'S_FILTER'=>			'Filtro',
	'S_TRIGGER_SEVERITY'=>			'Gravedad del iniciador',
	'S_TRIGGER_VALUE'=>			'Valor del iniciador',
	'S_TIME_PERIOD'=>			'Período de tiempo',
	'S_TRIGGER_DESCRIPTION'=>			'Descripción del iniciador',
	'S_CONDITIONS'=>			'Condiciones',
	'S_CONDITION'=>			'Condición',
	'S_NEW_CONDITION'=>			'Nueva condición',
	'S_OPERATIONS'=>			'Operaciones',
	'S_EDIT_OPERATION'=>			'Editar operación',
	'S_NO_CONDITIONS_DEFINED'=>			'No se han definido condiciones',
	'S_ACTIONS_DELETED'=>			'Acciones eliminadas',
	'S_CANNOT_DELETE_ACTIONS'=>			'No es posible eliminar las acciones',
	'S_NO_OPERATIONS_DEFINED'=>			'No se han definido operaciones',
	'S_NEW'=>			'Nuevo',
	'S_ADD_HOST'=>			'Añadir equipo',
	'S_REMOVE_HOST'=>			'Eliminar equipo',
	'S_LINK_TO_TEMPLATE'=>			'Vincular con plantilla',
	'S_UNLINK_FROM_TEMPLATE'=>			'Desvincular de plantilla',
	'S_INCORRECT_TRIGGER'=>			'Iniciador incorrecto',
	'S_INCORRECT_HOST'=>			'Equipo incorrecto',
	'S_INCORRECT_PERIOD'=>			'Período incorrecto',
	'S_INCORRECT_IP'=>			'IP incorrecta',
	'S_INCORRECT_DISCOVERY_CHECK'=>			'Comprobación de descubrimiento incorrecta',
	'S_INCORRECT_PORT'=>			'Puerto incorrecto',
	'S_INCORRECT_DISCOVERY_STATUS'=>			'Estado de descubrimiento incorrecto',
	'S_INCORRECT_CONDITION_TYPE'=>			'Tipo de condición incorrecta',
	'S_INCORRECT_OPERATION_TYPE'=>			'Tipo de operación incorrecta',
	'S_INCORRECT_USER'=>			'Usuario incorrecto',
	'S_ACTIONS'=>			'Acciones',
	'S_ACTIONS_BIG'=>			'ACCIONES',
	'S_ACTION_ADDED'=>			'Acción añadida',
	'S_CANNOT_ADD_ACTION'=>			'No es posible añadir la acción',
	'S_ACTION_UPDATED'=>			'Acción actualizada',
	'S_CANNOT_UPDATE_ACTION'=>			'No es posible actualizar la acción',
	'S_ACTION_DELETED'=>			'Acción eliminada',
	'S_CANNOT_DELETE_ACTION'=>			'No es posible eliminar la acción',
	'S_SEND_MESSAGE_TO'=>			'Enviar mensaje a',
	'S_RUN_REMOTE_COMMANDS'=>			'Ejecutar comandos remotos',
	'S_DELAY'=>			'Demora',
	'S_SUBJECT'=>			'Título',
	'S_ON'=>			'ACTIVO',
	'S_OFF'=>			'INACTIVO',
	'S_NO_ACTIONS_DEFINED'=>			'No se han definido acciones',
	'S_SINGLE_USER'=>			'Un usuario',
	'S_USER_GROUP'=>			'Un grupo de usuarios',
	'S_GROUP'=>			'Grupo',
	'S_USER'=>			'Usuario',
	'S_MESSAGE'=>			'Mensaje',
	'S_NOT_CLASSIFIED'=>			'No clasificada',
	'S_INFORMATION'=>			'Informativa',
	'S_WARNING'=>			'Baja',
	'S_AVERAGE'=>			'Media',
	'S_HIGH'=>			'Alta',
	'S_DISASTER'=>			'Crítica',
	'S_AND_OR_BIG'=>			'Y / O',
	'S_AND_BIG'=>			'Y',
	'S_AND'=>			'y',
	'S_OR_BIG'=>			'O',
	'S_OR'=>			'o',
	'S_TYPE_OF_CALCULATION'=>			'Tipo de cálculo',
	'S_CREATE_ACTION'=>			'Crear acción',
	'S_DELETE_SELECTED_ACTION_Q'=>			'¿Eliminar acción seleccionada?',
	'S_LIKE_SMALL'=>			'igual que',
	'S_NOT_LIKE_SMALL'=>			'distinto de',
	'S_IN_SMALL'=>			'contenido en',
	'S_NOT_IN_SMALL'=>			'no contenido en',
	'S_SHOW_ALL'=>			'Mostrar todo',
	'S_TIME'=>			'Fecha y hora',
	'S_STATUS'=>			'Estado',
	'S_DURATION'=>			'Duración',
	'S_TRUE_BIG'=>			'ACTIVO',
	'S_FALSE_BIG'=>			'INACTIVO',
	'S_UNKNOWN_BIG'=>			'DESCONOCIDO',
	'S_TYPE'=>			'Tipo',
	'S_RECIPIENTS'=>			'Receptor(es)',
	'S_ERROR'=>			'Error',
	'S_SENT'=>			'enviada',
	'S_NOT_SENT'=>			'no enviada',
	'S_NO_ACTIONS_FOUND'=>			'No se han encontrado acciones',
	'S_CUSTOM_GRAPHS'=>			'Personalizar gráficos',
	'S_GRAPHS_BIG'=>			'GRÁFICOS',
	'S_SELECT_GRAPH_TO_DISPLAY'=>			'Seleccionar el gráfico a mostrar',
	'S_PERIOD'=>			'Período',
	'S_SELECT_GRAPH_DOT_DOT_DOT'=>			'Seleccionar gráfico...',
	'S_CANNNOT_UPDATE_VALUE_MAP'=>			'No es posible actualizar la asignación',
	'S_VALUE_MAP_ADDED'=>			'Asignación añadida',
	'S_CANNNOT_ADD_VALUE_MAP'=>			'No es posible añadir la asignación',
	'S_VALUE_MAP_DELETED'=>			'Asignación eliminada',
	'S_CANNNOT_DELETE_VALUE_MAP'=>			'No es posible eliminar la asignación',
	'S_VALUE_MAP_UPDATED'=>			'Asignación actualizada',
	'S_VALUE_MAPPING_BIG'=>			'ASIGNACIÓN DE VALORES',
	'S_VALUE_MAPPING'=>			'Asignación de valores',
	'S_VALUE_MAP'=>			'Valor => Cadena asignada',
	'S_MAPPING'=>			'Creando asginación',
	'S_NEW_MAPPING'=>			'Creando nueva asignación',
	'S_NO_MAPPING_DEFINED'=>			'No se han definido asignaciones',
	'S_CREATE_VALUE_MAP'=>			'Asignar nuevo valor',
	'S_CONFIGURATION_OF_ZABBIX'=>			'Configuración de ZABBIX',
	'S_CONFIGURATION_OF_ZABBIX_BIG'=>			'CONFIGURACIÓN DE ZABBIX',
	'S_CONFIGURATION_UPDATED'=>			'Configuración actualizada',
	'S_CONFIGURATION_WAS_NOT_UPDATED'=>			'Configuración no actualizada',
	'S_ADDED_NEW_MEDIA_TYPE'=>			'Nuevo tipo de medio añadido',
	'S_NEW_MEDIA_TYPE_WAS_NOT_ADDED'=>			'Nuevo tipo de medio no añadido',
	'S_MEDIA_TYPE_UPDATED'=>			'Tipo de medio actualizado',
	'S_MEDIA_TYPE_WAS_NOT_UPDATED'=>			'Tipo de medio no actualizado',
	'S_MEDIA_TYPE_DELETED'=>			'Tipo de medio eliminado',
	'S_MEDIA_TYPE_WAS_NOT_DELETED'=>			'Tipo de medio no eliminado',
	'S_CONFIGURATION'=>			'Configuración',
	'S_ADMINISTRATION'=>			'Administración',
	'S_DO_NOT_KEEP_ACTIONS_OLDER_THAN'=>			'No mantener las acciones más de (en días))',
	'S_DO_NOT_KEEP_EVENTS_OLDER_THAN'=>			'No mantener los eventos más de (en días)',
	'S_NO_MEDIA_TYPES_DEFINED'=>			'No se han definido tipos de medios',
	'S_SMTP_SERVER'=>			'Servidor SMTP',
	'S_SMTP_HELO'=>			'SMTP helo',
	'S_SMTP_EMAIL'=>			'SMTP email',
	'S_SCRIPT_NAME'=>			'Nombre del script',
	'S_DELETE_SELECTED_MEDIA'=>			'¿Eliminar el tipo de medio seleccionado?',
	'S_DELETE_SELECTED_IMAGE'=>			'¿Eliminar la imágen seleccionada?',
	'S_HOUSEKEEPER'=>			'Caducidad para acciones y eventos',
	'S_MEDIA_TYPES'=>			'Tipos de medios',
	'S_ESCALATION_RULES'=>			'Reglas de escalado',
	'S_ESCALATION'=>			'Escalado',
	'S_ESCALATION_RULE'=>			'Regla de escalado',
	'S_DEFAULT'=>			'Por defecto',
	'S_IMAGES'=>			'Imágenes',
	'S_IMAGE'=>			'Imágen',
	'S_IMAGES_BIG'=>			'IMÁGENES',
	'S_ICON'=>			'Icono',
	'S_NO_IMAGES_DEFINED'=>			'No se han definido imágenes',
	'S_BACKGROUND'=>			'Fondo',
	'S_UPLOAD'=>			'Cargar',
	'S_IMAGE_ADDED'=>			'Imágen añadida',
	'S_CANNOT_ADD_IMAGE'=>			'No es posible añadir la imágen',
	'S_IMAGE_DELETED'=>			'Imágen eliminada',
	'S_CANNOT_DELETE_IMAGE'=>			'No es posible eliminar la imágen',
	'S_IMAGE_UPDATED'=>			'Imágen actualizada',
	'S_CANNOT_UPDATE_IMAGE'=>			'No es posible actualizar la imágen',
	'S_OTHER'=>			'Otras configuraciones',
	'S_OTHER_PARAMETERS'=>			'Otras configuraciones',
	'S_REFRESH_UNSUPPORTED_ITEMS'=>			'Tiempo de refresco para monitores no soportados en (segudos)',
	'S_CREATE_MEDIA_TYPE'=>			'Crear Tipo de Medio',
	'S_CREATE_IMAGE'=>			'Crear Imágen',
	'S_WORKING_TIME'=>			'Jornada laboral',
	'S_USER_GROUP_FOR_DATABASE_DOWN_MESSAGE'=>			'Grupo de usuarios para mensajes de base de datos caída',
	'S_INCORRECT_GROUP'=>			'Grupo incorrecto',
	'S_NOTHING_TO_DO'=>			'Nada que hacer',
	'S_INCORRECT_WORK_PERIOD'=>			'Período de trabajo incorrecto',
	'S_NODE'=>			'Nodo',
	'S_NODES'=>			'Nodos',
	'S_NODES_BIG'=>			'NODOS',
	'S_NEW_NODE'=>			'Nuevo nodo',
	'S_NO_NODES_DEFINED'=>			'No se han definido nodos',
	'S_NO_PERMISSIONS'=>			'Sin permisos !',
	'S_LATEST_DATA_BIG'=>			'ÚLTIMA FECHA',
	'S_ALL_SMALL'=>			'todo',
	'S_MINUS_ALL_MINUS'=>			'- todo -',
	'S_MINUS_OTHER_MINUS'=>			'- otros -',
	'S_GRAPH'=>			'Gráficos',
	'S_COPYRIGHT_BY'=>			'Copyright 2001-2007 por',
	'S_CONNECTED_AS'=>			'Conectado como',
	'S_SIA_ZABBIX'=>			'SIA Zabbix',
	'S_ITEM_ADDED'=>			'Monitor añadido',
	'S_ITEM_UPDATED'=>			'Monitor actualizado',
	'S_ITEMS_UPDATED'=>			'Monitores actualizados',
	'S_PARAMETER'=>			'Parámetro',
	'S_COLOR'=>			'Color',
	'S_UP'=>			'Arriba',
	'S_DOWN'=>			'Abajo',
	'S_NEW_ITEM_FOR_THE_GRAPH'=>			'Nuevo elemento para el gráfico',
	'S_SORT_ORDER_0_100'=>			'Órden de clasificación (0->100)',
	'S_YAXIS_SIDE'=>			'Lado del eje Y',
	'S_LEFT'=>			'Izquierda',
	'S_FUNCTION'=>			'Función',
	'S_MIN_SMALL'=>			'mínimo',
	'S_AVG_SMALL'=>			'media',
	'S_MAX_SMALL'=>			'máximo',
	'S_DRAW_STYLE'=>			'Estilo del trazado',
	'S_SIMPLE'=>			'Sencillo',
	'S_GRAPH_TYPE'=>			'Tipo de gráfico',
	'S_STACKED'=>			'Apilado',
	'S_NORMAL'=>			'Normal',
	'S_AGGREGATED'=>			'Añadido',
	'S_AGGREGATED_PERIODS_COUNT'=>			'Contadores de períodos añadidos',
	'S_CONFIGURATION_OF_GRAPHS'=>			'Configuración de los gráficos',
	'S_CONFIGURATION_OF_GRAPHS_BIG'=>			'CONFIGURACIÓN DE LOS GRÁFICOS',
	'S_GRAPH_ADDED'=>			'Gráfico añadido',
	'S_GRAPH_UPDATED'=>			'Gráfico actualizado',
	'S_CANNOT_UPDATE_GRAPH'=>			'No es posible actualizar el gráfico',
	'S_GRAPH_DELETED'=>			'Gráfico eliminado',
	'S_CANNOT_DELETE_GRAPH'=>			'No es posible eliminar el gráfico',
	'S_CANNOT_ADD_GRAPH'=>			'No es posible añadir el gráfico',
	'S_ID'=>			'Id',
	'S_NO_GRAPHS_DEFINED'=>			'No se han definido gráficos',
	'S_NO_GRAPH_DEFINED'=>			'No se ha definido gráfico',
	'S_DELETE_GRAPH_Q'=>			'¿Eliminar el gráfico?',
	'S_YAXIS_MIN_VALUE'=>			'Valor MIN del eje Y',
	'S_YAXIS_MAX_VALUE'=>			'Valor MAX del eje Y',
	'S_CALCULATED'=>			'Calculado',
	'S_FIXED'=>			'Fijo',
	'S_CREATE_GRAPH'=>			'Crear Gráfico',
	'S_SHOW_WORKING_TIME'=>			'Mostrar tiempo de trabajo',
	'S_SHOW_TRIGGERS'=>			'Mostrar iniciadores',
	'S_GRAPH_ITEM'=>			'Gráfico del elemento',
	'S_REQUIRED_ITEMS_FOR_GRAPH'=>			'Se requieren elementos para el gráfico',
	'S_LAST_HOUR_GRAPH'=>			'Gráfico de la última hora',
	'S_LAST_WEEK_GRAPH'=>			'Gráfico de la última semana',
	'S_LAST_MONTH_GRAPH'=>			'Gráfico del último mes',
	'S_500_LATEST_VALUES'=>			'Los 500 últimos valores',
	'S_TIMESTAMP'=>			'Feha y hora',
	'S_LOCAL'=>			'Local',
	'S_SOURCE'=>			'Orígen',
	'S_SHOW_SELECTED'=>			'Mostrar seleccionados',
	'S_HIDE_SELECTED'=>			'Ocultar seleccionados',
	'S_MARK_SELECTED'=>			'Marcar seleccionados',
	'S_MARK_OTHERS'=>			'Marcar otros',
	'S_AS_RED'=>			'Como Rojo',
	'S_AS_GREEN'=>			'Como Verde',
	'S_AS_BLUE'=>			'Como Azul',
	'S_APPLICATION'=>			'Aplicaciones',
	'S_APPLICATIONS'=>			'Aplicaciones',
	'S_APPLICATIONS_BIG'=>			'APLICACIONES',
	'S_CREATE_APPLICATION'=>			'Crear aplicación',
	'S_ACTIVATE_ITEMS'=>			'Activar',
	'S_DISABLE_ITEMS'=>			'Desactivar',
	'S_APPLICATION_UPDATED'=>			'Aplicación actualizada',
	'S_CANNOT_UPDATE_APPLICATION'=>			'No es posible actualizar la aplicación',
	'S_APPLICATION_ADDED'=>			'Aplicación añadida',
	'S_CANNOT_ADD_APPLICATION'=>			'No es posible añadir la aplicación',
	'S_APPLICATION_DELETED'=>			'Aplicación eliminada',
	'S_CANNOT_DELETE_APPLICATION'=>			'No es posible eliminar la aplicación',
	'S_NO_APPLICATIONS_DEFINED'=>			'No se han definido aplicaciones',
	'S_HOSTS'=>			'Equipos',
	'S_ITEMS'=>			'Monitores',
	'S_ITEMS_BIG'=>			'MONITORES',
	'S_TRIGGERS'=>			'Iniciadores',
	'S_GRAPHS'=>			'Gráficos',
	'S_HOST_ADDED'=>			'Equipo añadido',
	'S_CANNOT_ADD_HOST'=>			'No es posible añadir el equipo',
	'S_HOST_UPDATED'=>			'Equipo actualizado',
	'S_CANNOT_UPDATE_HOST'=>			'No es posible actualizar el equipo',
	'S_HOST_STATUS_UPDATED'=>			'Estado del equipo actualizado',
	'S_CANNOT_UPDATE_HOST_STATUS'=>			'No es posible actualizar el estado del equipo',
	'S_HOST_DELETED'=>			'Equipo eliminado',
	'S_CANNOT_DELETE_HOST'=>			'No es posible eliminar el equipo',
	'S_HOST_GROUPS_BIG'=>			'GRUPOS DE EQUIPOS',
	'S_NO_HOST_GROUPS_DEFINED'=>			'No se han definido grupos de equipos',
	'S_NO_HOSTS_DEFINED'=>			'No se han definido equipos',
	'S_NO_TEMPLATES_DEFINED'=>			'No se han definido plantillas',
	'S_HOSTS_BIG'=>			'EQUIPOS',
	'S_HOST'=>			'Equipo/Plantilla',
	'S_CONNECT_TO'=>			'Conectado a',
	'S_DNS'=>			'DNS',
	'S_IP'=>			'IP',
	'S_PORT'=>			'Puerto',
	'S_MONITORED'=>			'Monitorizado',
	'S_NOT_MONITORED'=>			'No monitorizado',
	'S_TEMPLATE'=>			'Plantilla',
	'S_DELETED'=>			'Eliminado',
	'S_UNKNOWN'=>			'Desconocido',
	'S_GROUPS'=>			'Grupos',
	'S_NO_GROUPS_DEFINED'=>			'No se han definido grupos',
	'S_NEW_GROUP'=>			'Nuevo grupo',
	'S_DNS_NAME'=>			'Nombre DNS',
	'S_IP_ADDRESS'=>			'Dirección IP',
	'S_LINK_WITH_TEMPLATE'=>			'Vincular con plantilla',
	'S_USE_PROFILE'=>			'Utilizar perfil',
	'S_DELETE_SELECTED_HOST_Q'=>			'¿Eliminar equipo seleccionado?',
	'S_DELETE_SELECTED_WITH_LINKED_ELEMENTS'=>			'Eliminar selección junto con los elementos vinculados',
	'S_GROUP_NAME'=>			'Nombre del grupo',
	'S_HOST_GROUP'=>			'Grupo del equipo',
	'S_HOST_GROUPS'=>			'Grupos de equipos',
	'S_UPDATE'=>			'Actualizar',
	'S_AVAILABILITY'=>			'Disponibilidad',
	'S_AVAILABLE'=>			'Disponible',
	'S_NOT_AVAILABLE'=>			'No disponible',
	'S_HOST_PROFILE'=>			'Perfil del equipo',
	'S_DEVICE_TYPE'=>			'Tipo de dispositivo',
	'S_OS'=>			'Sistema Operativo',
	'S_SERIALNO'=>			'Nº de serie',
	'S_TAG'=>			'Etiqueta',
	'S_HARDWARE'=>			'Hardware',
	'S_SOFTWARE'=>			'Software',
	'S_CONTACT'=>			'Contacto',
	'S_LOCATION'=>			'Localización',
	'S_NOTES'=>			'Notas',
	'S_MACADDRESS'=>			'Dirección MAC',
	'S_ADD_TO_GROUP'=>			'Añadir al grupo',
	'S_DELETE_FROM_GROUP'=>			'Eliminar del grupo',
	'S_UPDATE_IN_GROUP'=>			'Actualizar en el grupo',
	'S_DELETE_SELECTED_HOSTS_Q'=>			'¿Eliminar equipos seleccionados?',
	'S_CREATE_HOST'=>			'Crear Equipo',
	'S_CREATE_TEMPLATE'=>			'Crear Plantilla',
	'S_TEMPLATE_LINKAGE'=>			'Plantilla vinculada',
	'S_TEMPLATES'=>			'Plantillas',
	'S_TEMPLATES_BIG'=>			'PLANTILLAS',
	'S_UNLINK'=>			'Desvincular',
	'S_UNLINK_AND_CLEAR'=>			'Desvincular y eliminar',
	'S_NO_ITEMS_DEFINED'=>			'No se han definido monitores',
	'S_NO_ITEM_DEFINED'=>			'No se ha definido monitor',
	'S_HISTORY_CLEARED'=>			'Histórico eliminado',
	'S_CLEAR_HISTORY_FOR_SELECTED'=>			'Eliminar histórico del monitor seleccionado',
	'S_CLEAR_HISTORY'=>			'Eliminar histórico',
	'S_CANNOT_CLEAR_HISTORY'=>			'No es posible eliminar el histórico',
	'S_CONFIGURATION_OF_ITEMS'=>			'Configuración de monitores',
	'S_CONFIGURATION_OF_ITEMS_BIG'=>			'CONFIGURACIÓN DE MONITORES',
	'S_CANNOT_UPDATE_ITEM'=>			'No es posible actualizar el monitor',
	'S_STATUS_UPDATED'=>			'Estado actualizado',
	'S_CANNOT_UPDATE_STATUS'=>			'No es posible actualizar el estado',
	'S_CANNOT_ADD_ITEM'=>			'No es posible añadir el monitor',
	'S_ITEM_DELETED'=>			'Monitor eliminado',
	'S_CANNOT_DELETE_ITEM'=>			'No es posible eliminar el monitor',
	'S_ITEMS_DELETED'=>			'Monitores eliminados',
	'S_CANNOT_DELETE_ITEMS'=>			'No es posible eliminar los monitores',
	'S_ITEMS_ACTIVATED'=>			'Monitores activados',
	'S_ITEMS_DISABLED'=>			'Monitores desactivados',
	'S_KEY'=>			'Monitor',
	'S_DESCRIPTION'=>			'Nombre descriptivo',
	'S_UPDATE_INTERVAL'=>			'Refrescar cada (s)',
	'S_HISTORY'=>			'Histórico (días)',
	'S_TRENDS'=>			'Tendencias (días)',
	'S_ZABBIX_AGENT'=>			'Agente ZABBIX',
	'S_ZABBIX_AGENT_ACTIVE'=>			'Agente ZABBIX (activo)',
	'S_SNMPV1_AGENT'=>			'Agente SNMPv1',
	'S_ZABBIX_TRAPPER'=>			'Trapper ZABBIX',
	'S_SIMPLE_CHECK'=>			'Comprobación sencilla',
	'S_SNMPV2_AGENT'=>			'Agente SNMPv2',
	'S_SNMPV3_AGENT'=>			'Agente SNMPv3',
	'S_ZABBIX_INTERNAL'=>			'ZABBIX interno',
	'S_ZABBIX_AGGREGATE'=>			'ZABBIX añadido',
	'S_EXTERNAL_CHECK'=>			'Comprobación externa',
	'S_WEB_MONITORING'=>			'Monitorización Web',
	'S_ACTIVE'=>			'Activado',
	'S_NOT_SUPPORTED'=>			'No soportado',
	'S_EMAIL'=>			'Email',
	'S_JABBER'=>			'Jabber',
	'S_JABBER_IDENTIFIER'=>			'Identificador Jabber',
	'S_SMS'=>			'SMS',
	'S_SCRIPT'=>			'Script',
	'S_GSM_MODEM'=>			'Modem GSM',
	'S_UNITS'=>			'Unidad',
	'S_UPDATE_INTERVAL_IN_SEC'=>			'Intervalo de actualización (en segundos)',
	'S_KEEP_HISTORY_IN_DAYS'=>			'Conservar el histórico durante (en días)',
	'S_KEEP_TRENDS_IN_DAYS'=>			'Conservar las tendencias durante (en días)',
	'S_TYPE_OF_INFORMATION'=>			'Tipo de información',
	'S_STORE_VALUE'=>			'Valor almacenado',
	'S_SHOW_VALUE'=>			'Mostrar valor',
	'S_NUMERIC_UNSIGNED'=>			'Numérico (entero de 64 bits)',
	'S_NUMERIC_FLOAT'=>			'Numérico (coma flotante)',
	'S_CHARACTER'=>			'Carácter',
	'S_LOG'=>			'Registro',
	'S_TEXT'=>			'Texto',
	'S_AS_IS'=>			'Como sea',
	'S_DELTA_SPEED_PER_SECOND'=>			'Delta (velocidad por segundo)',
	'S_DELTA_SIMPLE_CHANGE'=>			'Delta (cambio sencillo)',
	'S_ITEM'=>			'Monitor',
	'S_SNMP_COMMUNITY'=>			'Comunidad SNMP',
	'S_SNMP_OID'=>			'SNMP OID',
	'S_SNMP_PORT'=>			'Puerto SNMP',
	'S_ALLOWED_HOSTS'=>			'Equipos permitidos',
	'S_SNMPV3_SECURITY_NAME'=>			'Nombre de seguridad SNMPv3',
	'S_SNMPV3_SECURITY_LEVEL'=>			'Nivel de seguridad SNMPv3',
	'S_SNMPV3_AUTH_PASSPHRASE'=>			'Frase de contraseña autorizada SNMPv3',
	'S_SNMPV3_PRIV_PASSPHRASE'=>			'Frase de contraseña privada SNMPv3',
	'S_CUSTOM_MULTIPLIER'=>			'Personalizar multiplicador',
	'S_DO_NOT_USE'=>			'No utilizar',
	'S_USE_MULTIPLIER'=>			'Utilizar multiplicador',
	'S_SELECT_HOST_DOT_DOT_DOT'=>			'Seleccionar equipo...',
	'S_LOG_TIME_FORMAT'=>			'Formato de fecha para el registro',
	'S_CREATE_ITEM'=>			'Crear monitor',
	'S_X_ELEMENTS_COPY_TO_DOT_DOT_DOT'=>			'Elementos copiados a...',
	'S_MODE'=>			'Modo',
	'S_TARGET'=>			'Destino',
	'S_TARGET_TYPE'=>			'Tipo de destino',
	'S_SKIP_EXISTING_ITEMS'=>			'Saltar monitores existentes',
	'S_UPDATE_EXISTING_NON_LINKED_ITEMS'=>			'Actualizar monitores no vinculados',
	'S_COPY'=>			'Copiar',
	'S_SHOW_ITEMS_WITH_DESCRIPTION_LIKE'=>			'Mostrar monitores cuya descripción sea',
	'S_HISTORY_CLEARING_CAN_TAKE_A_LONG_TIME_CONTINUE_Q'=>			'Eliminar el histórico puede llevarse tiempo. ¿Continuar?',
	'S_MASS_UPDATE'=>			'Actualizar masivamente',
	'S_SEARCH'=>			'Buscar',
	'S_ORIGINAL'=>			'Original',
	'S_NEW_FLEXIBLE_INTERVAL'=>			'Nuevo intervalo flexible',
	'S_FLEXIBLE_INTERVALS'=>			'Intervalos flexibles (sec)',
	'S_LATEST_EVENTS'=>			'Últimos eventos',
	'S_HISTORY_OF_EVENTS_BIG'=>			'HISTÓRICO DE EVENTOS',
	'S_NO_EVENTS_FOUND'=>			'No se han encontrado eventos',
	'S_LAST_CHECK'=>			'Última comprobación',
	'S_LAST_VALUE'=>			'Último valor',
	'S_LINK'=>			'Vínculo',
	'S_LABEL'=>			'Etiqueta',
	'S_X'=>			'X',
	'S_Y'=>			'Y',
	'S_ICON_UNKNOWN'=>			'Icono (desconocido)',
	'S_LINK_STATUS_INDICATOR'=>			'Vincular con el estado del iniciador',
	'S_CONFIGURATION_OF_NETWORK_MAPS'=>			'CONFIGURACIÓN DE LOS MAPAS DE LA RED',
	'S_MAPS_BIG'=>			'MAPAS',
	'S_NO_MAPS_DEFINED'=>			'No se han definido mapas',
	'S_CREATE_MAP'=>			'Crear Mapa',
	'S_ICON_LABEL_LOCATION'=>			'Localización de la etiqueta del icono',
	'S_BOTTOM'=>			'Debajo',
	'S_TOP'=>			'Encima',
	'S_OK_BIG'=>			'OK',
	'S_ZABBIX_URL'=>			'http://www.zabbix.com',
	'S_NETWORK_MAPS'=>			'Mapas de la red',
	'S_NETWORK_MAPS_BIG'=>			'MAPAS DE LA RED',
	'S_BACKGROUND_IMAGE'=>			'Imagen de fondo',
	'S_ICON_LABEL_TYPE'=>			'Tipo de etiqueta para el icono',
	'S_LABEL_LOCATION'=>			'Posición de la etiqueta',
	'S_ELEMENT_NAME'=>			'Nombre del elemento',
	'S_STATUS_ONLY'=>			'Sólo el estado',
	'S_NOTHING'=>			'Nada',
	'S_CONFIGURATION_OF_MEDIA_TYPES_BIG'=>			'CONFIGURACIÓN DE TIPOS DE MEDIO',
	'S_MEDIA'=>			'Medio',
	'S_SEND_TO'=>			'Enviar a',
	'S_WHEN_ACTIVE'=>			'Cuando se active',
	'S_NO_MEDIA_DEFINED'=>			'No se han definido medios',
	'S_NEW_MEDIA'=>			'Nuevo medio',
	'S_USE_IF_SEVERITY'=>			'Utilizar si la gravedad es',
	'S_SAVE'=>			'Guardar',
	'S_CANCEL'=>			'Cancelar',
	'S_OVERVIEW'=>			'Vistazo general',
	'S_OVERVIEW_BIG'=>			'VISTAZO GENERAL',
	'S_DATA'=>			'Monitores',
	'S_SHOW_GRAPH_OF_ITEM'=>			'Mostrar gráficos del elemento',
	'S_SHOW_VALUES_OF_ITEM'=>			'Mostrar valores del elemento',
	'S_VALUES'=>			'Valores',
	'S_5_MIN'=>			'5 minutos',
	'S_15_MIN'=>			'15 minutos',
	'S_QUEUE_BIG'=>			'COLA',
	'S_QUEUE_OF_ITEMS_TO_BE_UPDATED_BIG'=>			'COLA DE MONITORES PARA SER ACTUALIZADOS',
	'S_NEXT_CHECK'=>			'Próxima comprobación',
	'S_THE_QUEUE_IS_EMPTY'=>			'La cola está vacía',
	'S_TOTAL'=>			'Total',
	'S_COUNT'=>			'Contador',
	'S_5_SECONDS'=>			'5 segundos',
	'S_10_SECONDS'=>			'10 segundos',
	'S_30_SECONDS'=>			'30 segundos',
	'S_1_MINUTE'=>			'1 minuto',
	'S_5_MINUTES'=>			'5 minutos',
	'S_STATUS_OF_ZABBIX'=>			'Estado de ZABBIX',
	'S_STATUS_OF_ZABBIX_BIG'=>			'ESTADO DE ZABBIX',
	'S_VALUE'=>			'Estado',
	'S_ZABBIX_SERVER_IS_RUNNING'=>			'Servidor ZABBIX operativo',
	'S_VALUES_STORED'=>			'Valores almacenados',
	'S_TRENDS_STORED'=>			'Tendencias almacenadas',
	'S_NUMBER_OF_EVENTS'=>			'Número de eventos',
	'S_NUMBER_OF_ALERTS'=>			'Número de alertas',
	'S_NUMBER_OF_TRIGGERS'=>			'Número de iniciadores (activos/inactivos)[problemas/desconocidos/correctos]',
	'S_NUMBER_OF_TRIGGERS_SHORT'=>			'Iniciadores (a/i)[p/d/c]',
	'S_NUMBER_OF_ITEMS'=>			'Número de monitores (monitorizados/inactivos/no soportados)[trapper]',
	'S_NUMBER_OF_ITEMS_SHORT'=>			'Monitores(m/d/n)[t]',
	'S_NUMBER_OF_USERS'=>			'Número de usuarios(en línea)',
	'S_NUMBER_OF_USERS_SHORT'=>			'Usuarios (en línea)',
	'S_NUMBER_OF_HOSTS'=>			'Número de equipos/plantillas (monitorizados/no monitorizados/plantillas/eliminados)',
	'S_NUMBER_OF_HOSTS_SHORT'=>			'Equipos (m/n/p/e)',
	'S_YES'=>			'Si',
	'S_NO'=>			'No',
	'S_RUNNING'=>			'Ejecutándose',
	'S_NOT_RUNNING'=>			'No ejecutándose',
	'S_AVAILABILITY_REPORT'=>			'Informe de disponibilidad',
	'S_AVAILABILITY_REPORT_BIG'=>			'INFORME DE DISPONIBILIDAD',
	'S_SHOW'=>			'Mostrar',
	'S_IT_SERVICES_AVAILABILITY_REPORT'=>			'Informe de disponibilidad de servicios TI',
	'S_IT_SERVICES_AVAILABILITY_REPORT_BIG'=>			'INFORME DE DISPONIBILIDAD DE SERVICIOS TI',
	'S_FROM'=>			'Desde',
	'S_FROM_SMALL'=>			'desde',
	'S_TILL'=>			'Hasta',
	'S_OK'=>			'Ok',
	'S_PROBLEMS'=>			'Problemas',
	'S_PERCENTAGE'=>			'Porcentaje',
	'S_SLA'=>			'SLA',
	'S_DAY'=>			'Día',
	'S_MONTH'=>			'Mes',
	'S_YEAR'=>			'Año',
	'S_DAILY'=>			'Diario',
	'S_WEEKLY'=>			'Semanal',
	'S_MONTHLY'=>			'Mensual',
	'S_YEARLY'=>			'Anual',
	'S_NOTIFICATIONS'=>			'Notificaciones',
	'S_NOTIFICATIONS_BIG'=>			'NOTIFICACIONES',
	'S_IT_NOTIFICATIONS'=>			'Informe de notificaciones',
	'S_TRIGGERS_TOP_100'=>			'Los 100 iniciadores más volátiles',
	'S_TRIGGERS_TOP_100_BIG'=>			'LOS 100 INICIADORES MÁS VOLÁTILES',
	'S_NUMBER_OF_STATUS_CHANGES'=>			'Número de cambios de estado',
	'S_WEEK'=>			'Semana',
	'S_LAST'=>			'Último',
	'S_SCREENS'=>			'Pantallas',
	'S_SCREEN'=>			'Pantalla',
	'S_CONFIGURATION_OF_SCREENS_BIG'=>			'CONFIGURACIÓN DE LAS PANTALLAS',
	'S_CONFIGURATION_OF_SCREENS'=>			'Configuración de las pantallas',
	'S_SCREEN_ADDED'=>			'Pantalla añadida',
	'S_CANNOT_ADD_SCREEN'=>			'No es posible añadir la pantalla',
	'S_SCREEN_UPDATED'=>			'Pantalla actualizada',
	'S_CANNOT_UPDATE_SCREEN'=>			'No es posible actualizar la pantalla',
	'S_SCREEN_DELETED'=>			'Pantalla eliminada',
	'S_CANNOT_DELETE_SCREEN'=>			'No es posible eliminar la pantalla',
	'S_COLUMNS'=>			'Columnas',
	'S_ROWS'=>			'Filas',
	'S_NO_SCREENS_DEFINED'=>			'No se han definido pantallas',
	'S_DELETE_SCREEN_Q'=>			'¿Eliminar pantalla?',
	'S_CONFIGURATION_OF_SCREEN_BIG'=>			'CONFIGURACIÓN DE LA PANTALLA',
	'S_SCREEN_CELL_CONFIGURATION'=>			'Configuración de la celda de la pantalla',
	'S_RESOURCE'=>			'Recurso',
	'S_RIGHTS_OF_RESOURCES'=>			'Derechos del usuario',
	'S_NO_RESOURCES_DEFINED'=>			'No se han definido recursos',
	'S_SIMPLE_GRAPH'=>			'Gráfico sencillo',
	'S_GRAPH_NAME'=>			'Nombre del gráfico',
	'S_WIDTH'=>			'Anchura',
	'S_HEIGHT'=>			'Altura',
	'S_CREATE_SCREEN'=>			'Crear pantalla',
	'S_EDIT'=>			'Editar',
	'S_DIMENSION_COLS_ROWS'=>			'Dimensiones (columnas x filas)',
	'S_SLIDESHOWS'=>			'Diapositivas',
	'S_SLIDESHOW'=>			'Diapositiva',
	'S_CONFIGURATION_OF_SLIDESHOWS_BIG'=>			'CONFIGURACIÓN DE LAS DIAPOSITIVAS',
	'S_SLIDESHOWS_BIG'=>			'DIAPOSITIVAS',
	'S_NO_SLIDESHOWS_DEFINED'=>			'No se han definido diapositivas',
	'S_COUNT_OF_SLIDES'=>			'Contador de diapositivas',
	'S_NO_SLIDES_DEFINED'=>			'No se han definido diapositivas',
	'S_SLIDES'=>			'Diapositivas',
	'S_NEW_SLIDE'=>			'Nueva diapositiva',
	'S_MAP'=>			'Mapa',
	'S_AS_PLAIN_TEXT'=>			'Como texto plano',
	'S_PLAIN_TEXT'=>			'Texto plano',
	'S_COLUMN_SPAN'=>			'Separación de columna',
	'S_ROW_SPAN'=>			'Separación de fila',
	'S_SHOW_LINES'=>			'Mostrar líneas',
	'S_HOSTS_INFO'=>			'Información de los equipos',
	'S_TRIGGERS_INFO'=>			'Información de los iniciadores',
	'S_SERVER_INFO'=>			'Información del servidor',
	'S_CLOCK'=>			'Reloj',
	'S_TRIGGERS_OVERVIEW'=>			'Vistazo general de los iniciadores',
	'S_DATA_OVERVIEW'=>			'Vistado general de los datos',
	'S_HISTORY_OF_ACTIONS'=>			'Histórico de acciones',
	'S_HISTORY_OF_EVENTS'=>			'Histórico de eventos',
	'S_TIME_TYPE'=>			'Tipo de tiempo',
	'S_SERVER_TIME'=>			'Hora del sevidor',
	'S_LOCAL_TIME'=>			'Tiempo local',
	'S_STYLE'=>			'Estilo',
	'S_VERTICAL'=>			'Vertical',
	'S_HORIZONTAL'=>			'Horizontal',
	'S_HORIZONTAL_ALIGN'=>			'Alineación horizontal',
	'S_CENTRE'=>			'Centro',
	'S_RIGHT'=>			'Derecho',
	'S_VERTICAL_ALIGN'=>			'Alineación vertical',
	'S_MIDDLE'=>			'Medio',
	'S_CUSTOM_SCREENS'=>			'Personalizar pantallas',
	'S_SCREENS_BIG'=>			'PANTALLAS',
	'S_SLIDESHOW_UPDATED'=>			'Diapositiva actualizada',
	'S_CANNOT_UPDATE_SLIDESHOW'=>			'No es posible actualizar la diapositiva',
	'S_SLIDESHOW_ADDED'=>			'Diapositiva añadida',
	'S_CANNOT_ADD_SLIDESHOW'=>			'No es posible añadir la diapositiva',
	'S_SLIDESHOW_DELETED'=>			'Diapositiva eliminada',
	'S_CANNOT_DELETE_SLIDESHOW'=>			'No es posible eliminar la diapositiva',
	'S_DELETE_SLIDESHOW_Q'=>			'¿Eliminar la diapositiva?',
	'S_ROOT_SMALL'=>			'root',
	'S_IT_SERVICE'=>			'Servicio TI',
	'S_IT_SERVICES'=>			'Servicios TI',
	'S_SERVICE_UPDATED'=>			'Servicio actualizado',
	'S_NO_IT_SERVICE_DEFINED'=>			'No IT service defined',
	'S_CANNOT_UPDATE_SERVICE'=>			'No es posible actualizar el servicio',
	'S_SERVICE_ADDED'=>			'Servicio añadido',
	'S_CANNOT_ADD_SERVICE'=>			'No es posible añadir el servicio',
	'S_SERVICE_DELETED'=>			'Servicio eliminado',
	'S_CANNOT_DELETE_SERVICE'=>			'No es posible eliminar el servicio',
	'S_STATUS_CALCULATION'=>			'Cálculo del estado',
	'S_STATUS_CALCULATION_ALGORITHM'=>			'Algoritmo para el cálculo del estado',
	'S_NONE'=>			'Ninguno',
	'S_SOFT'=>			'Blando',
	'S_DO_NOT_CALCULATE'=>			'No calculado',
	'S_ACCEPTABLE_SLA_IN_PERCENT'=>			'SLA aceptable (en %)',
	'S_LINK_TO_TRIGGER_Q'=>			'¿Vincular al iniciador?',
	'S_SORT_ORDER_0_999'=>			'Orden de clasificación (0->999)',
	'S_TRIGGER'=>			'Iniciadores',
	'S_SERVER'=>			'Servidor',
	'S_DELETE'=>			'Eliminar',
	'S_CLONE'=>			'Clonar',
	'S_UPTIME'=>			'Tiempo operativo',
	'S_DOWNTIME'=>			'Tiempo inoperativo',
	'S_ONE_TIME_DOWNTIME'=>			'Una vez inoperativo',
	'S_NO_TIMES_DEFINED'=>			'No se han definido tiempos',
	'S_SERVICE_TIMES'=>			'Tiempos del servicio',
	'S_NEW_SERVICE_TIME'=>			'Nuevo tiempo del servicio',
	'S_NOTE'=>			'Nota',
	'S_REMOVE'=>			'Eliminar',
	'S_DEPENDS_ON'=>			'Depende de',
	'S_SUNDAY'=>			'Domingo',
	'S_MONDAY'=>			'Lunes',
	'S_TUESDAY'=>			'Martes',
	'S_WEDNESDAY'=>			'Miércoles',
	'S_THURSDAY'=>			'Jueves',
	'S_FRIDAY'=>			'Viernes',
	'S_SATURDAY'=>			'Sábado',
	'S_IT_SERVICES_BIG'=>			'SERVICIOS TI',
	'S_SERVICE'=>			'Servicio',
	'S_SERVICES'=>			'Servicios',
	'S_REASON'=>			'Causa',
	'S_NO_TRIGGER'=>			'Sin iniciadores',
	'S_NO_TRIGGERS_DEFINED'=>			'No se han definido iniciadores',
	'S_NO_TRIGGER_DEFINED'=>			'No se ha definido iniciador',
	'S_CONFIGURATION_OF_TRIGGERS'=>			'Configuración del iniciador',
	'S_CONFIGURATION_OF_TRIGGERS_BIG'=>			'CONFIGURACIÓN DEL INICIADOR',
	'S_TRIGGERS_DELETED'=>			'Iniciadores eliminados',
	'S_CANNOT_DELETE_TRIGGERS'=>			'No es posible eliminar los iniciadores',
	'S_TRIGGER_DELETED'=>			'Iniciador eliminado',
	'S_CANNOT_DELETE_TRIGGER'=>			'No es posible eliminar los iniciadores',
	'S_TRIGGER_ADDED'=>			'Iniciador añadido',
	'S_CANNOT_ADD_TRIGGER'=>			'No es posible añadir el iniciador',
	'S_SEVERITY'=>			'Gravedad',
	'S_EXPRESSION'=>			'Expresión',
	'S_DISABLED'=>			'Desactivado',
	'S_ENABLED'=>			'Activado',
	'S_ENABLE_SELECTED'=>			'Activar',
	'S_CHANGE'=>			'Variación con valor anterior',
	'S_TRIGGER_UPDATED'=>			'Iniciador actualizado',
	'S_CANNOT_UPDATE_TRIGGER'=>			'No es posible actualizar el iniciador',
	'S_URL'=>			'URL',
	'S_CREATE_TRIGGER'=>			'Crear iniciador',
	'S_INSERT'=>			'Insertar',
	'S_SECONDS'=>			'Segundos',
	'S_SEC_SMALL'=>			'seg',
	'S_LAST_OF'=>			'El último de',
	'S_SHOW_DISABLED_TRIGGERS'=>			'Mostrar iniciadores desactivados',
	'S_HIDE_DISABLED_TRIGGERS'=>			'Ocultar iniciadores desactivados',
	'S_TRIGGER_COMMENTS'=>			'Comentarios del iniciador',
	'S_TRIGGER_COMMENTS_BIG'=>			'COMENTARIOS DEL INICIADOR',
	'S_COMMENT_UPDATED'=>			'Comentario actualizado',
	'S_CANNOT_UPDATE_COMMENT'=>			'No es posible actualizar el comentario',
	'S_ADD'=>			'Añadir',
	'S_STATUS_OF_TRIGGERS'=>			'Estado de los iniciadores',
	'S_STATUS_OF_TRIGGERS_BIG'=>			'ESTADO DE LOS INICIADORES',
	'S_SHOW_DETAILS'=>			'Mostrar detalles',
	'S_SELECT'=>			'Seleccionar / Examinar...',
	'S_TRIGGERS_BIG'=>			'INICIADORES',
	'S_LAST_CHANGE'=>			'Último cambio',
	'S_COMMENTS'=>			'Comentarios',
	'S_ACKNOWLEDGED'=>			'Aceptada',
	'S_ACK'=>			'Aceptar',
	'S_NEVER'=>			'Nunca',
	'S_ZABBIX_USER'=>			'Usuario ZABBIX',
	'S_ZABBIX_ADMIN'=>			'Administrador ZABBIX',
	'S_SUPER_ADMIN'=>			'Super Administrador ZABBIX',
	'S_USER_TYPE'=>			'Tipo de usuario',
	'S_USERS'=>			'Usuarios',
	'S_USER_ADDED'=>			'Usuario añadido',
	'S_CANNOT_ADD_USER'=>			'No es posible añadir al usuario',
	'S_CANNOT_ADD_USER_BOTH_PASSWORDS_MUST'=>			'No es posible añadir al usuario. Ambas contraseñas deben ser iguales.',
	'S_USER_DELETED'=>			'Usuario eliminado',
	'S_CANNOT_DELETE_USER'=>			'No es posible eliminar al usuario',
	'S_USER_UPDATED'=>			'Usuario actualizado',
	'S_CANNOT_UPDATE_USER'=>			'No es posible actualizar al usuario',
	'S_CANNOT_UPDATE_USER_BOTH_PASSWORDS'=>			'No es posible actualizar al usuario. Ambas contraseñas deben ser iguales.',
	'S_GROUP_ADDED'=>			'Grupo añadido',
	'S_CANNOT_ADD_GROUP'=>			'No es posible añadir el grupo',
	'S_GROUP_UPDATED'=>			'Grupo actualizado',
	'S_CANNOT_UPDATE_GROUP'=>			'No es posible actualizar el grupo',
	'S_GROUP_DELETED'=>			'Grupo eliminado',
	'S_CANNOT_DELETE_GROUP'=>			'No es posible eliminar el grupo',
	'S_CONFIGURATION_OF_USERS_AND_USER_GROUPS'=>			'CONFIGURACION DE USUARIOS Y DE GRUPOS DE USUARIOS',
	'S_USER_GROUPS_BIG'=>			'GRUPOS DE USUARIOS',
	'S_USERS_BIG'=>			'USUARIOS',
	'S_USER_GROUPS'=>			'Grupos de usuarios',
	'S_MEMBERS'=>			'Miembros',
	'S_NO_USER_GROUPS_DEFINED'=>			'No se han definio grupos de usuarios',
	'S_ALIAS'=>			'Alias',
	'S_NAME'=>			'Nombre',
	'S_SURNAME'=>			'Apellido',
	'S_IS_ONLINE_Q'=>			'¿Está conectado?',
	'S_NO_USERS_DEFINED'=>			'No se han definido usuarios',
	'S_RIGHTS'=>			'Derechos',
	'S_NO_RIGHTS_DEFINED'=>			'No se han definido derechos',
	'S_READ_ONLY'=>			'Sólo lectura',
	'S_READ_WRITE'=>			'Lectura-escritura',
	'S_DENY'=>			'Denegar',
	'S_HIDE'=>			'Ocultar',
	'S_PASSWORD'=>			'Contraseña',
	'S_CHANGE_PASSWORD'=>			'Cambiar la contraseña',
	'S_PASSWORD_ONCE_AGAIN'=>			'Contraseña (de nuevo)',
	'S_URL_AFTER_LOGIN'=>			'URL (después de iniciar sesión)',
	'S_SCREEN_REFRESH'=>			'Refrescar (en segundos)',
	'S_CREATE_USER'=>			'Crear Usuario',
	'S_CREATE_GROUP'=>			'Crear Grupo',
	'S_DELETE_SELECTED_USERS_Q'=>			'¿Eliminar usuarios seccionados?',
	'S_NO_ACCESSIBLE_RESOURCES'=>			'Sin recursos accesibles',
	'S_ACTION'=>			'Acción',
	'S_DETAILS'=>			'Detalles',
	'S_UNKNOWN_ACTION'=>			'Acción desconocida',
	'S_ADDED'=>			'Añadido',
	'S_UPDATED'=>			'Actualizado',
	'S_MEDIA_TYPE'=>			'Tipo de medio',
	'S_GRAPH_ELEMENT'=>			'Elemento del gráfico',
	'S_UNKNOWN_RESOURCE'=>			'Recurso desconocido',
	'S_USER_PROFILE_BIG'=>			'PERFIL DE USUARIO',
	'S_USER_PROFILE'=>			'Perfil de usuario',
	'S_LANGUAGE'=>			'Idioma',
	'S_ENGLISH_GB'=>			'Inglés (GB)',
	'S_FRENCH_FR'=>			'Francés (FR)',
	'S_GERMAN_DE'=>			'Alemán(DE)',
	'S_ITALIAN_IT'=>			'Italiano (IT)',
	'S_LATVIAN_LV'=>			'Letón (LV)',
	'S_RUSSIAN_RU'=>			'Ruso (RU)',
	'S_SPANISH_SP'=>			'Español (SP)',
	'S_SWEDISH_SE'=>			'Sueco (SE)',
	'S_JAPANESE_JP'=>			'Japonés (JP)',
	'S_CHINESE_CN'=>			'Chino (CN)',
	'S_DUTCH_NL'=>			'Holandés (NL)',
	'S_ZABBIX_BIG'=>			'ZABBIX',
	'S_HOST_PROFILES'=>			'Perfiles del equipo',
	'S_HOST_PROFILES_BIG'=>			'PERFILES DEL EQUIPO',
	'S_EMPTY'=>			'Sin contenido',
	'S_STANDARD_ITEMS_BIG'=>			'ALERTAS CONVENCIONALES',
	'S_NO_ITEMS'=>			'Sin alertas',
	'S_HELP'=>			'Ayuda',
	'S_PROFILE'=>			'Perfiles',
	'S_GET_SUPPORT'=>			'Obtener soporte',
	'S_MONITORING'=>			'Monitorización',
	'S_INVENTORY'=>			'Inventario',
	'S_QUEUE'=>			'Cola',
	'S_EVENTS'=>			'Eventos',
	'S_EVENTS_BIG'=>			'EVENTOS',
	'S_MAPS'=>			'Mapas',
	'S_REPORTS'=>			'Informes',
	'S_GENERAL'=>			'Zabbix',
	'S_AUDIT'=>			'Auditoría',
	'S_LOGIN'=>			'Iniciar sesión',
	'S_LOGOUT'=>			'Finalizar sesión',
	'S_LATEST_DATA'=>			'Última fecha',
	'S_INCORRECT_DESCRIPTION'=>			'Descripción incorrecta',
	'S_CANT_FORMAT_TREE'=>			'No es posible dar formato al Árbol',

	);
?>
